@@ -17,7 +17,7 @@ sub new
 sub parse_response
 {
     my $self = shift;
-    $self->libxml->parse_string( $_[0]->content );
+    $self->libxml->parse_string( $_[0]->decoded_content );
 }
 
 1;
@@ -43,4 +43,4 @@ WebService::Simple::Parser::XML::LibXML - Parse XML content using XML::LibXML
 
 =head2 parse_response
 
-=cut
\ No newline at end of file
+=cut
